# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class OpenFlowChannel(Base):
	"""The OpenFlowChannel class encapsulates a user managed openFlowChannel node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the OpenFlowChannel property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server using the find method.
	The internal properties list can be managed by the user by using the add and remove methods.
	"""

	_SDM_NAME = 'openFlowChannel'

	def __init__(self, parent):
		super(OpenFlowChannel, self).__init__(parent)

	@property
	def Groups(self):
		"""An instance of the Groups class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.groups.Groups)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.groups import Groups
		return Groups(self)

	@property
	def Meters(self):
		"""An instance of the Meters class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.meters.Meters)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.meters import Meters
		return Meters(self)

	@property
	def Tables(self):
		"""An instance of the Tables class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.tables.Tables)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.tables import Tables
		return Tables(self)

	@property
	def Active(self):
		"""Activate/Deactivate Configuration

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('active')

	@property
	def CalcFlowRate(self):
		"""If selected, the statistics on the rate of transmission of flows per second by the controller is published.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('calcFlowRate')

	@property
	def CalcFlowRateWithBarrier(self):
		"""If selected, statistics on the rate of transmission of flows per second by the controller, along with Barrier Request messages is published.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('calcFlowRateWithBarrier')

	@property
	def ConnectedVia(self):
		"""DEPRECATED List of layers this layer used to connect to the wire

		Returns:
			list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])
		"""
		return self._get_attribute('connectedVia')
	@ConnectedVia.setter
	def ConnectedVia(self, value):
		self._set_attribute('connectedVia', value)

	@property
	def ControllerIndex(self):
		"""DEPRECATED Parent Controller Index

		Returns:
			list(str)
		"""
		return self._get_attribute('controllerIndex')

	@property
	def ControllerName(self):
		"""DEPRECATED Parent Controller Name

		Returns:
			str
		"""
		return self._get_attribute('controllerName')

	@property
	def Count(self):
		"""DEPRECATED Number of elements inside associated multiplier-scaled container object, e.g. number of devices inside a Device Group

		Returns:
			number
		"""
		return self._get_attribute('count')

	@property
	def DatapathId(self):
		"""DEPRECATED The Datapath ID of the OF Channel.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('datapathId')

	@property
	def DatapathIdHex(self):
		"""DEPRECATED The Datapath ID in hexadecimal format.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('datapathIdHex')

	@property
	def DescriptiveName(self):
		"""DEPRECATED Longer, more descriptive name for element. It's not guaranteed to be unique like -name-, but maybe offers more context

		Returns:
			str
		"""
		return self._get_attribute('descriptiveName')

	@property
	def EnableHelloElement(self):
		"""DEPRECATED If selected, the Controller sends a hello message consisting of an OpenFlow header and a set of variable size hello elements to inform the initial handshake of the connection.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('enableHelloElement')

	@property
	def Errors(self):
		"""DEPRECATED A list of errors that have occurred

		Returns:
			list(dict(arg1:str[None|/api/v1/sessions/1/ixnetwork/?deepchild=*],arg2:list[str]))
		"""
		return self._get_attribute('errors')

	@property
	def FlowTxBurstSize(self):
		"""DEPRECATED Specify the number of Flow transmitting packets that can be sent in a single burst within the time frame specified by the Inter Flow Burst Gap value.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('flowTxBurstSize')

	@property
	def GroupsPerChannel(self):
		"""DEPRECATED Number of Groups per Channel

		Returns:
			number
		"""
		return self._get_attribute('groupsPerChannel')
	@GroupsPerChannel.setter
	def GroupsPerChannel(self, value):
		self._set_attribute('groupsPerChannel', value)

	@property
	def InterFlowBurstGap(self):
		"""DEPRECATED Specify the duration (in milliseconds) for which the controller waits between successive flow advertisements.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('interFlowBurstGap')

	@property
	def LocalIp(self):
		"""DEPRECATED The local IP address of the interface. This field is auto-populated and cannot be changed.

		Returns:
			list(str)
		"""
		return self._get_attribute('localIp')

	@property
	def MaxFlowsAtATime(self):
		"""DEPRECATED The Max Number of Flows Processed at a Time is the size of an internal buffer maintained by the Ixiacontroller, which prevents it from sending more flows than the Openflow switch can consume at a time.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('maxFlowsAtATime')

	@property
	def MetersPerChannel(self):
		"""DEPRECATED Number of Meters per Channel

		Returns:
			number
		"""
		return self._get_attribute('metersPerChannel')
	@MetersPerChannel.setter
	def MetersPerChannel(self, value):
		self._set_attribute('metersPerChannel', value)

	@property
	def Multiplier(self):
		"""DEPRECATED Number of layer instances per parent instance (multiplier)

		Returns:
			number
		"""
		return self._get_attribute('multiplier')
	@Multiplier.setter
	def Multiplier(self, value):
		self._set_attribute('multiplier', value)

	@property
	def Name(self):
		"""DEPRECATED Name of NGPF element, guaranteed to be unique in Scenario

		Returns:
			str
		"""
		return self._get_attribute('name')
	@Name.setter
	def Name(self, value):
		self._set_attribute('name', value)

	@property
	def RemoteIp(self):
		"""DEPRECATED The IP address of the DUT at the other end of the OF Channel.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('remoteIp')

	@property
	def SendRoleRequest(self):
		"""DEPRECATED If selected, the controller sends a Role Request message after the connection is established; to change its role according to the Role Request option selected.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('sendRoleRequest')

	@property
	def SessionStatus(self):
		"""DEPRECATED Current state of protocol session: Not Started - session negotiation not started, the session is not active yet. Down - actively trying to bring up a protocol session, but negotiation is didn't successfully complete (yet). Up - session came up successfully.

		Returns:
			list(str[down|notStarted|up])
		"""
		return self._get_attribute('sessionStatus')

	@property
	def StackedLayers(self):
		"""DEPRECATED List of secondary (many to one) child layer protocols

		Returns:
			list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])
		"""
		return self._get_attribute('stackedLayers')
	@StackedLayers.setter
	def StackedLayers(self, value):
		self._set_attribute('stackedLayers', value)

	@property
	def StartupGenerationId(self):
		"""DEPRECATED A 64-bit sequence number field that identifies a given mastership view.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('startupGenerationId')

	@property
	def StartupRoleRequest(self):
		"""DEPRECATED This defines role of the controller.Options include: 1) No Change 2) Equal 3) Master 4) Slave

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('startupRoleRequest')

	@property
	def StateCounts(self):
		"""DEPRECATED A list of values that indicates the total number of sessions, the number of sessions not started, the number of sessions down and the number of sessions that are up

		Returns:
			dict(total:number,notStarted:number,down:number,up:number)
		"""
		return self._get_attribute('stateCounts')

	@property
	def Status(self):
		"""DEPRECATED Running status of associated network element. Once in Started state, protocol sessions will begin to negotiate.

		Returns:
			str(configured|error|mixed|notStarted|started|starting|stopping)
		"""
		return self._get_attribute('status')

	@property
	def TablesPerChannel(self):
		"""DEPRECATED Number of Tables per Channel

		Returns:
			number
		"""
		return self._get_attribute('tablesPerChannel')
	@TablesPerChannel.setter
	def TablesPerChannel(self, value):
		self._set_attribute('tablesPerChannel', value)

	@property
	def UseDatapathID(self):
		"""DEPRECATED If selected, the Datapath ID and IP address are used as the OF Channel identifier.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('useDatapathID')

	def update(self, ConnectedVia=None, GroupsPerChannel=None, MetersPerChannel=None, Multiplier=None, Name=None, StackedLayers=None, TablesPerChannel=None):
		"""Updates a child instance of openFlowChannel on the server.

		This method has some named parameters with a type: obj (Multivalue).
		The Multivalue class has the associated documentation that details the possible values for those named parameters.

		Args:
			ConnectedVia (list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])): List of layers this layer used to connect to the wire
			GroupsPerChannel (number): Number of Groups per Channel
			MetersPerChannel (number): Number of Meters per Channel
			Multiplier (number): Number of layer instances per parent instance (multiplier)
			Name (str): Name of NGPF element, guaranteed to be unique in Scenario
			StackedLayers (list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])): List of secondary (many to one) child layer protocols
			TablesPerChannel (number): Number of Tables per Channel

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def add(self, ConnectedVia=None, GroupsPerChannel=None, MetersPerChannel=None, Multiplier=None, Name=None, StackedLayers=None, TablesPerChannel=None):
		"""Adds a new openFlowChannel node on the server and retrieves it in this instance.

		Args:
			ConnectedVia (list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])): List of layers this layer used to connect to the wire
			GroupsPerChannel (number): Number of Groups per Channel
			MetersPerChannel (number): Number of Meters per Channel
			Multiplier (number): Number of layer instances per parent instance (multiplier)
			Name (str): Name of NGPF element, guaranteed to be unique in Scenario
			StackedLayers (list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])): List of secondary (many to one) child layer protocols
			TablesPerChannel (number): Number of Tables per Channel

		Returns:
			self: This instance with all currently retrieved openFlowChannel data using find and the newly added openFlowChannel data available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._create(locals())

	def remove(self):
		"""Deletes all the openFlowChannel data in this instance from server.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._delete()

	def find(self, ConnectedVia=None, ControllerIndex=None, ControllerName=None, Count=None, DescriptiveName=None, Errors=None, GroupsPerChannel=None, LocalIp=None, MetersPerChannel=None, Multiplier=None, Name=None, SessionStatus=None, StackedLayers=None, StateCounts=None, Status=None, TablesPerChannel=None):
		"""Finds and retrieves openFlowChannel data from the server.

		All named parameters support regex and can be used to selectively retrieve openFlowChannel data from the server.
		By default the find method takes no parameters and will retrieve all openFlowChannel data from the server.

		Args:
			ConnectedVia (list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])): List of layers this layer used to connect to the wire
			ControllerIndex (list(str)): Parent Controller Index
			ControllerName (str): Parent Controller Name
			Count (number): Number of elements inside associated multiplier-scaled container object, e.g. number of devices inside a Device Group
			DescriptiveName (str): Longer, more descriptive name for element. It's not guaranteed to be unique like -name-, but maybe offers more context
			Errors (list(dict(arg1:str[None|/api/v1/sessions/1/ixnetwork/?deepchild=*],arg2:list[str]))): A list of errors that have occurred
			GroupsPerChannel (number): Number of Groups per Channel
			LocalIp (list(str)): The local IP address of the interface. This field is auto-populated and cannot be changed.
			MetersPerChannel (number): Number of Meters per Channel
			Multiplier (number): Number of layer instances per parent instance (multiplier)
			Name (str): Name of NGPF element, guaranteed to be unique in Scenario
			SessionStatus (list(str[down|notStarted|up])): Current state of protocol session: Not Started - session negotiation not started, the session is not active yet. Down - actively trying to bring up a protocol session, but negotiation is didn't successfully complete (yet). Up - session came up successfully.
			StackedLayers (list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])): List of secondary (many to one) child layer protocols
			StateCounts (dict(total:number,notStarted:number,down:number,up:number)): A list of values that indicates the total number of sessions, the number of sessions not started, the number of sessions down and the number of sessions that are up
			Status (str(configured|error|mixed|notStarted|started|starting|stopping)): Running status of associated network element. Once in Started state, protocol sessions will begin to negotiate.
			TablesPerChannel (number): Number of Tables per Channel

		Returns:
			self: This instance with matching openFlowChannel data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of openFlowChannel data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the openFlowChannel data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)

	def get_device_ids(self, PortNames=None, Active=None, CalcFlowRate=None, CalcFlowRateWithBarrier=None, DatapathId=None, DatapathIdHex=None, EnableHelloElement=None, FlowTxBurstSize=None, InterFlowBurstGap=None, MaxFlowsAtATime=None, RemoteIp=None, SendRoleRequest=None, StartupGenerationId=None, StartupRoleRequest=None, UseDatapathID=None):
		"""Base class infrastructure that gets a list of openFlowChannel device ids encapsulated by this object.

		Use the optional regex parameters in the method to refine the list of device ids encapsulated by this object.

		Args:
			PortNames (str): optional regex of port names
			Active (str): optional regex of active
			CalcFlowRate (str): optional regex of calcFlowRate
			CalcFlowRateWithBarrier (str): optional regex of calcFlowRateWithBarrier
			DatapathId (str): optional regex of datapathId
			DatapathIdHex (str): optional regex of datapathIdHex
			EnableHelloElement (str): optional regex of enableHelloElement
			FlowTxBurstSize (str): optional regex of flowTxBurstSize
			InterFlowBurstGap (str): optional regex of interFlowBurstGap
			MaxFlowsAtATime (str): optional regex of maxFlowsAtATime
			RemoteIp (str): optional regex of remoteIp
			SendRoleRequest (str): optional regex of sendRoleRequest
			StartupGenerationId (str): optional regex of startupGenerationId
			StartupRoleRequest (str): optional regex of startupRoleRequest
			UseDatapathID (str): optional regex of useDatapathID

		Returns:
			list(int): A list of device ids that meets the regex criteria provided in the method parameters

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._get_ngpf_device_ids(locals())

	def FetchAndUpdateConfigFromCloud(self, *args, **kwargs):
		"""Executes the fetchAndUpdateConfigFromCloud operation on the server.

		fetchAndUpdateConfigFromCloud(Mode:string)
			Args:
				args[0] is Mode (str): 

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('fetchAndUpdateConfigFromCloud', payload=payload, response_object=None)

	def GetAsynchronousConfiguration(self, *args, **kwargs):
		"""Executes the getAsynchronousConfiguration operation on the server.

		Get Asynchronous Configurationr

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		getAsynchronousConfiguration()

		getAsynchronousConfiguration(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		getAsynchronousConfiguration(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		getAsynchronousConfiguration(Arg2:list)list
			Args:
				args[0] is Arg2 (list(number)): List of indices into the protocol plugin. An empty list indicates all instances in the plugin.

			Returns:
				list(str): ID to associate each async action invocation

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('getAsynchronousConfiguration', payload=payload, response_object=None)

	def InvokeSendRoleRequest(self, *args, **kwargs):
		"""Executes the invokeSendRoleRequest operation on the server.

		Sends a Role Request for selected Channel.

		invokeSendRoleRequest(Arg2:list)list
			Args:
				args[0] is Arg2 (list(number)): List of indices in channel grid

			Returns:
				list(str): ID to associate each async action invocation

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('invokeSendRoleRequest', payload=payload, response_object=None)

	def PauseEchoReply(self, *args, **kwargs):
		"""Executes the pauseEchoReply operation on the server.

		Pause Sending Echo Reply Messages

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		pauseEchoReply()

		pauseEchoReply(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		pauseEchoReply(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		pauseEchoReply(Arg2:list)list
			Args:
				args[0] is Arg2 (list(number)): List of indices into the protocol plugin. An empty list indicates all instances in the plugin.

			Returns:
				list(str): ID to associate each async action invocation

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('pauseEchoReply', payload=payload, response_object=None)

	def PauseEchoRequest(self, *args, **kwargs):
		"""Executes the pauseEchoRequest operation on the server.

		Pause Sending Echo Request Messages

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		pauseEchoRequest()

		pauseEchoRequest(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		pauseEchoRequest(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		pauseEchoRequest(Arg2:list)list
			Args:
				args[0] is Arg2 (list(number)): List of indices into the protocol plugin. An empty list indicates all instances in the plugin.

			Returns:
				list(str): ID to associate each async action invocation

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('pauseEchoRequest', payload=payload, response_object=None)

	def RestartDown(self, *args, **kwargs):
		"""Executes the restartDown operation on the server.

		Stop and start interfaces and sessions that are in Down state.

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		restartDown()

		restartDown(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		restartDown(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('restartDown', payload=payload, response_object=None)

	def ResumeEchoReply(self, *args, **kwargs):
		"""Executes the resumeEchoReply operation on the server.

		Resume Sending Echo Reply Messages

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		resumeEchoReply()

		resumeEchoReply(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		resumeEchoReply(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		resumeEchoReply(Arg2:list)list
			Args:
				args[0] is Arg2 (list(number)): List of indices into the protocol plugin. An empty list indicates all instances in the plugin.

			Returns:
				list(str): ID to associate each async action invocation

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('resumeEchoReply', payload=payload, response_object=None)

	def ResumeEchoRequest(self, *args, **kwargs):
		"""Executes the resumeEchoRequest operation on the server.

		Resume Sending Echo Request Messages

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		resumeEchoRequest()

		resumeEchoRequest(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		resumeEchoRequest(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		resumeEchoRequest(Arg2:list)list
			Args:
				args[0] is Arg2 (list(number)): List of indices into the protocol plugin. An empty list indicates all instances in the plugin.

			Returns:
				list(str): ID to associate each async action invocation

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('resumeEchoRequest', payload=payload, response_object=None)

	def SendBarrierRequest(self, *args, **kwargs):
		"""Executes the sendBarrierRequest operation on the server.

		Send Barrier Request to Switch

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		sendBarrierRequest()

		sendBarrierRequest(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		sendBarrierRequest(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		sendBarrierRequest(Arg2:list)list
			Args:
				args[0] is Arg2 (list(number)): List of indices into the protocol plugin. An empty list indicates all instances in the plugin.

			Returns:
				list(str): ID to associate each async action invocation

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('sendBarrierRequest', payload=payload, response_object=None)

	def SendConfigRequest(self, *args, **kwargs):
		"""Executes the sendConfigRequest operation on the server.

		Send Config Request to Switch

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		sendConfigRequest()

		sendConfigRequest(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		sendConfigRequest(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		sendConfigRequest(Arg2:list)list
			Args:
				args[0] is Arg2 (list(number)): List of indices into the protocol plugin. An empty list indicates all instances in the plugin.

			Returns:
				list(str): ID to associate each async action invocation

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('sendConfigRequest', payload=payload, response_object=None)

	def SendDescriptionStatRequest(self, *args, **kwargs):
		"""Executes the sendDescriptionStatRequest operation on the server.

		Send Description Stat Request

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		sendDescriptionStatRequest()

		sendDescriptionStatRequest(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		sendDescriptionStatRequest(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		sendDescriptionStatRequest(Arg2:list)list
			Args:
				args[0] is Arg2 (list(number)): List of indices into the protocol plugin. An empty list indicates all instances in the plugin.

			Returns:
				list(str): ID to associate each async action invocation

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('sendDescriptionStatRequest', payload=payload, response_object=None)

	def SendEchoRequest(self, *args, **kwargs):
		"""Executes the sendEchoRequest operation on the server.

		Send Echo Request

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		sendEchoRequest(EnableEchoTimeout:bool, EchoTimeoutVal:number)
			Args:
				args[0] is EnableEchoTimeout (bool): This parameter requires a enableEchoTimeout of type kBool
				args[1] is EchoTimeoutVal (number): This parameter requires a echoTimeoutVal of type kInteger

		sendEchoRequest(EnableEchoTimeout:bool, EchoTimeoutVal:number, SessionIndices:list)
			Args:
				args[0] is EnableEchoTimeout (bool): This parameter requires a enableEchoTimeout of type kBool
				args[1] is EchoTimeoutVal (number): This parameter requires a echoTimeoutVal of type kInteger
				args[2] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		sendEchoRequest(SessionIndices:string, EnableEchoTimeout:bool, EchoTimeoutVal:number)
			Args:
				args[0] is SessionIndices (str): This parameter requires a enableEchoTimeout of type kBool
				args[1] is EnableEchoTimeout (bool): This parameter requires a echoTimeoutVal of type kInteger
				args[2] is EchoTimeoutVal (number): This parameter requires a string of session numbers 1-4;6;7-12

		sendEchoRequest(Arg2:list, Arg3:bool, Arg4:number)list
			Args:
				args[0] is Arg2 (list(number)): List of indices into the protocol plugin. An empty list indicates all instances in the plugin.
				args[1] is Arg3 (bool): Enable Echo Timeout
				args[2] is Arg4 (number): Echo Timeout Value

			Returns:
				list(str): ID to associate each async action invocation

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('sendEchoRequest', payload=payload, response_object=None)

	def SendExperimenterMessage(self, *args, **kwargs):
		"""Executes the sendExperimenterMessage operation on the server.

		Send Experimenter Message

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		sendExperimenterMessage(ExperimenterDataLength:number, ErrorUnsupportedTypeFormat:null, ErrorUnsupportedTypeFormat:null, ExperimenterData:string)
			Args:
				args[0] is ExperimenterDataLength (number): This parameter requires a experimenterDataLength of type kInteger
				args[1] is ErrorUnsupportedTypeFormat (null): This parameter requires a errorUnsupportedTypeFormat of type kVoid
				args[2] is ErrorUnsupportedTypeFormat (null): This parameter requires a errorUnsupportedTypeFormat of type kVoid
				args[3] is ExperimenterData (str): This parameter requires a experimenterData of type kString

		sendExperimenterMessage(ExperimenterDataLength:number, ErrorUnsupportedTypeFormat:null, ErrorUnsupportedTypeFormat:null, ExperimenterData:string, SessionIndices:list)
			Args:
				args[0] is ExperimenterDataLength (number): This parameter requires a experimenterDataLength of type kInteger
				args[1] is ErrorUnsupportedTypeFormat (null): This parameter requires a errorUnsupportedTypeFormat of type kVoid
				args[2] is ErrorUnsupportedTypeFormat (null): This parameter requires a errorUnsupportedTypeFormat of type kVoid
				args[3] is ExperimenterData (str): This parameter requires a experimenterData of type kString
				args[4] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		sendExperimenterMessage(SessionIndices:string, ExperimenterDataLength:number, ErrorUnsupportedTypeFormat:null, ErrorUnsupportedTypeFormat:null, ExperimenterData:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a experimenterDataLength of type kInteger
				args[1] is ExperimenterDataLength (number): This parameter requires a errorUnsupportedTypeFormat of type kVoid
				args[2] is ErrorUnsupportedTypeFormat (null): This parameter requires a errorUnsupportedTypeFormat of type kVoid
				args[3] is ErrorUnsupportedTypeFormat (null): This parameter requires a experimenterData of type kString
				args[4] is ExperimenterData (str): This parameter requires a string of session numbers 1-4;6;7-12

		sendExperimenterMessage(Arg2:list, Arg3:number, Arg4:number, Arg5:number, Arg6:string)list
			Args:
				args[0] is Arg2 (list(number)): List of indices into the protocol plugin. An empty list indicates all instances in the plugin.
				args[1] is Arg3 (number): Experimenter Data Length.
				args[2] is Arg4 (number): Experimenter ID.
				args[3] is Arg5 (number): Experimenter ID
				args[4] is Arg6 (str): Experimenter Data in Hex.

			Returns:
				list(str): ID to associate each async action invocation

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('sendExperimenterMessage', payload=payload, response_object=None)

	def SendExperimenterStatRequest(self, *args, **kwargs):
		"""Executes the sendExperimenterStatRequest operation on the server.

		Send Experimenter Stats Request

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		sendExperimenterStatRequest(ExperimenterDataLength:number, ErrorUnsupportedTypeFormat:null, ErrorUnsupportedTypeFormat:null, ExperimenterData:string)
			Args:
				args[0] is ExperimenterDataLength (number): This parameter requires a experimenterDataLength of type kInteger
				args[1] is ErrorUnsupportedTypeFormat (null): This parameter requires a errorUnsupportedTypeFormat of type kVoid
				args[2] is ErrorUnsupportedTypeFormat (null): This parameter requires a errorUnsupportedTypeFormat of type kVoid
				args[3] is ExperimenterData (str): This parameter requires a experimenterData of type kString

		sendExperimenterStatRequest(ExperimenterDataLength:number, ErrorUnsupportedTypeFormat:null, ErrorUnsupportedTypeFormat:null, ExperimenterData:string, SessionIndices:list)
			Args:
				args[0] is ExperimenterDataLength (number): This parameter requires a experimenterDataLength of type kInteger
				args[1] is ErrorUnsupportedTypeFormat (null): This parameter requires a errorUnsupportedTypeFormat of type kVoid
				args[2] is ErrorUnsupportedTypeFormat (null): This parameter requires a errorUnsupportedTypeFormat of type kVoid
				args[3] is ExperimenterData (str): This parameter requires a experimenterData of type kString
				args[4] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		sendExperimenterStatRequest(SessionIndices:string, ExperimenterDataLength:number, ErrorUnsupportedTypeFormat:null, ErrorUnsupportedTypeFormat:null, ExperimenterData:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a experimenterDataLength of type kInteger
				args[1] is ExperimenterDataLength (number): This parameter requires a errorUnsupportedTypeFormat of type kVoid
				args[2] is ErrorUnsupportedTypeFormat (null): This parameter requires a errorUnsupportedTypeFormat of type kVoid
				args[3] is ErrorUnsupportedTypeFormat (null): This parameter requires a experimenterData of type kString
				args[4] is ExperimenterData (str): This parameter requires a string of session numbers 1-4;6;7-12

		sendExperimenterStatRequest(Arg2:list, Arg3:number, Arg4:number, Arg5:number, Arg6:string)list
			Args:
				args[0] is Arg2 (list(number)): List of indices into the protocol plugin. An empty list indicates all instances in the plugin.
				args[1] is Arg3 (number): Experimenter Data Length.
				args[2] is Arg4 (number): Experimenter ID.
				args[3] is Arg5 (number): Experimenter ID
				args[4] is Arg6 (str): Experimenter Data in Hex.

			Returns:
				list(str): ID to associate each async action invocation

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('sendExperimenterStatRequest', payload=payload, response_object=None)

	def SendFeatureRequest(self, *args, **kwargs):
		"""Executes the sendFeatureRequest operation on the server.

		Send Feature Request to Switch

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		sendFeatureRequest()

		sendFeatureRequest(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		sendFeatureRequest(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		sendFeatureRequest(Arg2:list)list
			Args:
				args[0] is Arg2 (list(number)): List of indices into the protocol plugin. An empty list indicates all instances in the plugin.

			Returns:
				list(str): ID to associate each async action invocation

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('sendFeatureRequest', payload=payload, response_object=None)

	def SendGetQueueConfigRequest(self, *args, **kwargs):
		"""Executes the sendGetQueueConfigRequest operation on the server.

		Send Queue Stats Request

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		sendGetQueueConfigRequest(OutputPortType:enum, ErrorUnsupportedTypeFormat:null)
			Args:
				args[0] is OutputPortType (str(enumOpt-MANUAL|enumOpt-OFPP_ANY)): This parameter requires a outputPortType of type kEnumValue=enumOpt-MANUAL,enumOpt-OFPP_ANY
				args[1] is ErrorUnsupportedTypeFormat (null): This parameter requires a errorUnsupportedTypeFormat of type kVoid

		sendGetQueueConfigRequest(OutputPortType:enum, ErrorUnsupportedTypeFormat:null, SessionIndices:list)
			Args:
				args[0] is OutputPortType (str(enumOpt-MANUAL|enumOpt-OFPP_ANY)): This parameter requires a outputPortType of type kEnumValue=enumOpt-MANUAL,enumOpt-OFPP_ANY
				args[1] is ErrorUnsupportedTypeFormat (null): This parameter requires a errorUnsupportedTypeFormat of type kVoid
				args[2] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		sendGetQueueConfigRequest(SessionIndices:string, OutputPortType:enum, ErrorUnsupportedTypeFormat:null)
			Args:
				args[0] is SessionIndices (str): This parameter requires a outputPortType of type kEnumValue=enumOpt-MANUAL,enumOpt-OFPP_ANY
				args[1] is OutputPortType (str(enumOpt-MANUAL|enumOpt-OFPP_ANY)): This parameter requires a errorUnsupportedTypeFormat of type kVoid
				args[2] is ErrorUnsupportedTypeFormat (null): This parameter requires a string of session numbers 1-4;6;7-12

		sendGetQueueConfigRequest(Arg2:list, Arg3:enum, Arg4:number)list
			Args:
				args[0] is Arg2 (list(number)): List of indices into the protocol plugin. An empty list indicates all instances in the plugin.
				args[1] is Arg3 (str(mANUAL|oFPP_ALL|oFPP_ANY|oFPP_CONTROLLER|oFPP_FLOOD|oFPP_IN_PORT|oFPP_LOCAL|oFPP_NONE|oFPP_NORMAL|oFPP_TABLE)): Output Port Type
				args[2] is Arg4 (number): Port ID

			Returns:
				list(str): ID to associate each async action invocation

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('sendGetQueueConfigRequest', payload=payload, response_object=None)

	def SendGroupDescriptionRequest(self, *args, **kwargs):
		"""Executes the sendGroupDescriptionRequest operation on the server.

		Send Group Description Request to Switch

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		sendGroupDescriptionRequest()

		sendGroupDescriptionRequest(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		sendGroupDescriptionRequest(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		sendGroupDescriptionRequest(Arg2:list)list
			Args:
				args[0] is Arg2 (list(number)): List of indices into the protocol plugin. An empty list indicates all instances in the plugin.

			Returns:
				list(str): ID to associate each async action invocation

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('sendGroupDescriptionRequest', payload=payload, response_object=None)

	def SendGroupFeaturesRequest(self, *args, **kwargs):
		"""Executes the sendGroupFeaturesRequest operation on the server.

		Send Group Features Request to Switch

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		sendGroupFeaturesRequest()

		sendGroupFeaturesRequest(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		sendGroupFeaturesRequest(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		sendGroupFeaturesRequest(Arg2:list)list
			Args:
				args[0] is Arg2 (list(number)): List of indices into the protocol plugin. An empty list indicates all instances in the plugin.

			Returns:
				list(str): ID to associate each async action invocation

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('sendGroupFeaturesRequest', payload=payload, response_object=None)

	def SendGroupStatsRequest(self, *args, **kwargs):
		"""Executes the sendGroupStatsRequest operation on the server.

		Send Group Stats Request to Switch

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		sendGroupStatsRequest(GroupIDType:enum, GroupID:number)
			Args:
				args[0] is GroupIDType (str(enumOpt-Manual|enumOpt-OFPG_ALL|enumOpt-OFPG_ANY)): This parameter requires a groupIDType of type kEnumValue=enumOpt-Manual,enumOpt-OFPG_ALL,enumOpt-OFPG_ANY
				args[1] is GroupID (number): This parameter requires a groupID of type kInteger

		sendGroupStatsRequest(GroupIDType:enum, GroupID:number, SessionIndices:list)
			Args:
				args[0] is GroupIDType (str(enumOpt-Manual|enumOpt-OFPG_ALL|enumOpt-OFPG_ANY)): This parameter requires a groupIDType of type kEnumValue=enumOpt-Manual,enumOpt-OFPG_ALL,enumOpt-OFPG_ANY
				args[1] is GroupID (number): This parameter requires a groupID of type kInteger
				args[2] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		sendGroupStatsRequest(SessionIndices:string, GroupIDType:enum, GroupID:number)
			Args:
				args[0] is SessionIndices (str): This parameter requires a groupIDType of type kEnumValue=enumOpt-Manual,enumOpt-OFPG_ALL,enumOpt-OFPG_ANY
				args[1] is GroupIDType (str(enumOpt-Manual|enumOpt-OFPG_ALL|enumOpt-OFPG_ANY)): This parameter requires a groupID of type kInteger
				args[2] is GroupID (number): This parameter requires a string of session numbers 1-4;6;7-12

		sendGroupStatsRequest(Arg2:list, Arg3:enum, Arg4:number)list
			Args:
				args[0] is Arg2 (list(number)): List of indices into the protocol plugin. An empty list indicates all instances in the plugin.
				args[1] is Arg3 (str(manual|oFPG_ALL|oFPG_ANY)): Group ID Type
				args[2] is Arg4 (number): Group ID

			Returns:
				list(str): ID to associate each async action invocation

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('sendGroupStatsRequest', payload=payload, response_object=None)

	def SendMeterConfigRequest(self, *args, **kwargs):
		"""Executes the sendMeterConfigRequest operation on the server.

		Send Meter Config Request

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		sendMeterConfigRequest(MeterIDType:enum, ErrorUnsupportedTypeFormat:null)
			Args:
				args[0] is MeterIDType (str(enumOpt-ALL|enumOpt-MANUAL|enumOpt-OFPM_CONTROLLER|enumOpt-OFPM_SLOWPATH)): This parameter requires a meterIDType of type kEnumValue=enumOpt-ALL,enumOpt-MANUAL,enumOpt-OFPM_CONTROLLER,enumOpt-OFPM_SLOWPATH
				args[1] is ErrorUnsupportedTypeFormat (null): This parameter requires a errorUnsupportedTypeFormat of type kVoid

		sendMeterConfigRequest(MeterIDType:enum, ErrorUnsupportedTypeFormat:null, SessionIndices:list)
			Args:
				args[0] is MeterIDType (str(enumOpt-ALL|enumOpt-MANUAL|enumOpt-OFPM_CONTROLLER|enumOpt-OFPM_SLOWPATH)): This parameter requires a meterIDType of type kEnumValue=enumOpt-ALL,enumOpt-MANUAL,enumOpt-OFPM_CONTROLLER,enumOpt-OFPM_SLOWPATH
				args[1] is ErrorUnsupportedTypeFormat (null): This parameter requires a errorUnsupportedTypeFormat of type kVoid
				args[2] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		sendMeterConfigRequest(SessionIndices:string, MeterIDType:enum, ErrorUnsupportedTypeFormat:null)
			Args:
				args[0] is SessionIndices (str): This parameter requires a meterIDType of type kEnumValue=enumOpt-ALL,enumOpt-MANUAL,enumOpt-OFPM_CONTROLLER,enumOpt-OFPM_SLOWPATH
				args[1] is MeterIDType (str(enumOpt-ALL|enumOpt-MANUAL|enumOpt-OFPM_CONTROLLER|enumOpt-OFPM_SLOWPATH)): This parameter requires a errorUnsupportedTypeFormat of type kVoid
				args[2] is ErrorUnsupportedTypeFormat (null): This parameter requires a string of session numbers 1-4;6;7-12

		sendMeterConfigRequest(Arg2:list, Arg3:enum, Arg4:number)list
			Args:
				args[0] is Arg2 (list(number)): List of indices into the protocol plugin. An empty list indicates all instances in the plugin.
				args[1] is Arg3 (str(all|manual|oFPM_CONTROLLER|oFPM_SLOWPATH)): Meter ID Type
				args[2] is Arg4 (number): Meter ID

			Returns:
				list(str): ID to associate each async action invocation

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('sendMeterConfigRequest', payload=payload, response_object=None)

	def SendMeterFeaturesRequest(self, *args, **kwargs):
		"""Executes the sendMeterFeaturesRequest operation on the server.

		Send Meter Features Request to Switch

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		sendMeterFeaturesRequest()

		sendMeterFeaturesRequest(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		sendMeterFeaturesRequest(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		sendMeterFeaturesRequest(Arg2:list)list
			Args:
				args[0] is Arg2 (list(number)): List of indices into the protocol plugin. An empty list indicates all instances in the plugin.

			Returns:
				list(str): ID to associate each async action invocation

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('sendMeterFeaturesRequest', payload=payload, response_object=None)

	def SendMeterStatRequest(self, *args, **kwargs):
		"""Executes the sendMeterStatRequest operation on the server.

		Send Meter Stat Request to Switch.

		sendMeterStatRequest(Arg2:list, Arg3:enum, Arg4:number)list
			Args:
				args[0] is Arg2 (list(number)): List of indices into the protocol plugin. An empty list indicates all instances in the plugin.
				args[1] is Arg3 (str(all|manual|oFPM_CONTROLLER|oFPM_SLOWPATH)): Meter ID Type
				args[2] is Arg4 (number): Meter ID

			Returns:
				list(str): ID to associate each async action invocation

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('sendMeterStatRequest', payload=payload, response_object=None)

	def SendMeterStatsRequest(self, *args, **kwargs):
		"""Executes the sendMeterStatsRequest operation on the server.

		Send Meter Stats Request

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		sendMeterStatsRequest(MeterIDType:enum, ErrorUnsupportedTypeFormat:null)
			Args:
				args[0] is MeterIDType (str(enumOpt-ALL|enumOpt-MANUAL|enumOpt-OFPM_CONTROLLER|enumOpt-OFPM_SLOWPATH)): This parameter requires a meterIDType of type kEnumValue=enumOpt-ALL,enumOpt-MANUAL,enumOpt-OFPM_CONTROLLER,enumOpt-OFPM_SLOWPATH
				args[1] is ErrorUnsupportedTypeFormat (null): This parameter requires a errorUnsupportedTypeFormat of type kVoid

		sendMeterStatsRequest(MeterIDType:enum, ErrorUnsupportedTypeFormat:null, SessionIndices:list)
			Args:
				args[0] is MeterIDType (str(enumOpt-ALL|enumOpt-MANUAL|enumOpt-OFPM_CONTROLLER|enumOpt-OFPM_SLOWPATH)): This parameter requires a meterIDType of type kEnumValue=enumOpt-ALL,enumOpt-MANUAL,enumOpt-OFPM_CONTROLLER,enumOpt-OFPM_SLOWPATH
				args[1] is ErrorUnsupportedTypeFormat (null): This parameter requires a errorUnsupportedTypeFormat of type kVoid
				args[2] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		sendMeterStatsRequest(SessionIndices:string, MeterIDType:enum, ErrorUnsupportedTypeFormat:null)
			Args:
				args[0] is SessionIndices (str): This parameter requires a meterIDType of type kEnumValue=enumOpt-ALL,enumOpt-MANUAL,enumOpt-OFPM_CONTROLLER,enumOpt-OFPM_SLOWPATH
				args[1] is MeterIDType (str(enumOpt-ALL|enumOpt-MANUAL|enumOpt-OFPM_CONTROLLER|enumOpt-OFPM_SLOWPATH)): This parameter requires a errorUnsupportedTypeFormat of type kVoid
				args[2] is ErrorUnsupportedTypeFormat (null): This parameter requires a string of session numbers 1-4;6;7-12

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('sendMeterStatsRequest', payload=payload, response_object=None)

	def SendPortDescription(self, *args, **kwargs):
		"""Executes the sendPortDescription operation on the server.

		Send Port Description

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		sendPortDescription()

		sendPortDescription(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		sendPortDescription(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		sendPortDescription(Arg2:list)list
			Args:
				args[0] is Arg2 (list(number)): List of indices into the protocol plugin. An empty list indicates all instances in the plugin.

			Returns:
				list(str): ID to associate each async action invocation

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('sendPortDescription', payload=payload, response_object=None)

	def SendPortStatsRequest(self, *args, **kwargs):
		"""Executes the sendPortStatsRequest operation on the server.

		Send Port Stats Request

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		sendPortStatsRequest(OutputPortType:enum, ErrorUnsupportedTypeFormat:null)
			Args:
				args[0] is OutputPortType (str(enumOpt-MANUAL|enumOpt-OFPP_ANY|enumOpt-OFPP_NONE)): This parameter requires a outputPortType of type kEnumValue=enumOpt-MANUAL,enumOpt-OFPP_ANY,enumOpt-OFPP_NONE
				args[1] is ErrorUnsupportedTypeFormat (null): This parameter requires a errorUnsupportedTypeFormat of type kVoid

		sendPortStatsRequest(OutputPortType:enum, ErrorUnsupportedTypeFormat:null, SessionIndices:list)
			Args:
				args[0] is OutputPortType (str(enumOpt-MANUAL|enumOpt-OFPP_ANY|enumOpt-OFPP_NONE)): This parameter requires a outputPortType of type kEnumValue=enumOpt-MANUAL,enumOpt-OFPP_ANY,enumOpt-OFPP_NONE
				args[1] is ErrorUnsupportedTypeFormat (null): This parameter requires a errorUnsupportedTypeFormat of type kVoid
				args[2] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		sendPortStatsRequest(SessionIndices:string, OutputPortType:enum, ErrorUnsupportedTypeFormat:null)
			Args:
				args[0] is SessionIndices (str): This parameter requires a outputPortType of type kEnumValue=enumOpt-MANUAL,enumOpt-OFPP_ANY,enumOpt-OFPP_NONE
				args[1] is OutputPortType (str(enumOpt-MANUAL|enumOpt-OFPP_ANY|enumOpt-OFPP_NONE)): This parameter requires a errorUnsupportedTypeFormat of type kVoid
				args[2] is ErrorUnsupportedTypeFormat (null): This parameter requires a string of session numbers 1-4;6;7-12

		sendPortStatsRequest(Arg2:list, Arg3:enum, Arg4:number)list
			Args:
				args[0] is Arg2 (list(number)): List of indices into the protocol plugin. An empty list indicates all instances in the plugin.
				args[1] is Arg3 (str(mANUAL|oFPP_ALL|oFPP_ANY|oFPP_CONTROLLER|oFPP_FLOOD|oFPP_IN_PORT|oFPP_LOCAL|oFPP_NONE|oFPP_NORMAL|oFPP_TABLE)): Output Port Type
				args[2] is Arg4 (number): Port ID

			Returns:
				list(str): ID to associate each async action invocation

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('sendPortStatsRequest', payload=payload, response_object=None)

	def SendQueueStatsRequest(self, *args, **kwargs):
		"""Executes the sendQueueStatsRequest operation on the server.

		Send Queue Stats Request

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		sendQueueStatsRequest(OutputPortType:enum, ErrorUnsupportedTypeFormat:null, QueueType:enum, ErrorUnsupportedTypeFormat:null)
			Args:
				args[0] is OutputPortType (str(enumOpt-MANUAL|enumOpt-OFPP_ANY)): This parameter requires a outputPortType of type kEnumValue=enumOpt-MANUAL,enumOpt-OFPP_ANY
				args[1] is ErrorUnsupportedTypeFormat (null): This parameter requires a errorUnsupportedTypeFormat of type kVoid
				args[2] is QueueType (str(enumOpt-MANUAL|enumOpt-OFPQ_ALL)): This parameter requires a queueType of type kEnumValue=enumOpt-MANUAL,enumOpt-OFPQ_ALL
				args[3] is ErrorUnsupportedTypeFormat (null): This parameter requires a errorUnsupportedTypeFormat of type kVoid

		sendQueueStatsRequest(OutputPortType:enum, ErrorUnsupportedTypeFormat:null, QueueType:enum, ErrorUnsupportedTypeFormat:null, SessionIndices:list)
			Args:
				args[0] is OutputPortType (str(enumOpt-MANUAL|enumOpt-OFPP_ANY)): This parameter requires a outputPortType of type kEnumValue=enumOpt-MANUAL,enumOpt-OFPP_ANY
				args[1] is ErrorUnsupportedTypeFormat (null): This parameter requires a errorUnsupportedTypeFormat of type kVoid
				args[2] is QueueType (str(enumOpt-MANUAL|enumOpt-OFPQ_ALL)): This parameter requires a queueType of type kEnumValue=enumOpt-MANUAL,enumOpt-OFPQ_ALL
				args[3] is ErrorUnsupportedTypeFormat (null): This parameter requires a errorUnsupportedTypeFormat of type kVoid
				args[4] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		sendQueueStatsRequest(SessionIndices:string, OutputPortType:enum, ErrorUnsupportedTypeFormat:null, QueueType:enum, ErrorUnsupportedTypeFormat:null)
			Args:
				args[0] is SessionIndices (str): This parameter requires a outputPortType of type kEnumValue=enumOpt-MANUAL,enumOpt-OFPP_ANY
				args[1] is OutputPortType (str(enumOpt-MANUAL|enumOpt-OFPP_ANY)): This parameter requires a errorUnsupportedTypeFormat of type kVoid
				args[2] is ErrorUnsupportedTypeFormat (null): This parameter requires a queueType of type kEnumValue=enumOpt-MANUAL,enumOpt-OFPQ_ALL
				args[3] is QueueType (str(enumOpt-MANUAL|enumOpt-OFPQ_ALL)): This parameter requires a errorUnsupportedTypeFormat of type kVoid
				args[4] is ErrorUnsupportedTypeFormat (null): This parameter requires a string of session numbers 1-4;6;7-12

		sendQueueStatsRequest(Arg2:list, Arg3:enum, Arg4:number, Arg5:enum, Arg6:number)list
			Args:
				args[0] is Arg2 (list(number)): List of indices into the protocol plugin. An empty list indicates all instances in the plugin.
				args[1] is Arg3 (str(mANUAL|oFPP_ALL|oFPP_ANY|oFPP_CONTROLLER|oFPP_FLOOD|oFPP_IN_PORT|oFPP_LOCAL|oFPP_NONE|oFPP_NORMAL|oFPP_TABLE)): Output Port Type
				args[2] is Arg4 (number): Port ID
				args[3] is Arg5 (str(manual|oFPQ_ALL)): Queue Type
				args[4] is Arg6 (number): Queue ID

			Returns:
				list(str): ID to associate each async action invocation

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('sendQueueStatsRequest', payload=payload, response_object=None)

	def SendTableModRequest(self, *args, **kwargs):
		"""Executes the sendTableModRequest operation on the server.

		Send Table Mod Request

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		sendTableModRequest(TableIdType:enum, TableId:number, ErrorUnsupportedTypeFormat:null)
			Args:
				args[0] is TableIdType (str(enumOpt-ALL_TABLE|enumOpt-MANUAL)): This parameter requires a tableIdType of type kEnumValue=enumOpt-ALL_TABLE,enumOpt-MANUAL
				args[1] is TableId (number): This parameter requires a tableId of type kInteger
				args[2] is ErrorUnsupportedTypeFormat (null): This parameter requires a errorUnsupportedTypeFormat of type kVoid

		sendTableModRequest(TableIdType:enum, TableId:number, ErrorUnsupportedTypeFormat:null, SessionIndices:list)
			Args:
				args[0] is TableIdType (str(enumOpt-ALL_TABLE|enumOpt-MANUAL)): This parameter requires a tableIdType of type kEnumValue=enumOpt-ALL_TABLE,enumOpt-MANUAL
				args[1] is TableId (number): This parameter requires a tableId of type kInteger
				args[2] is ErrorUnsupportedTypeFormat (null): This parameter requires a errorUnsupportedTypeFormat of type kVoid
				args[3] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		sendTableModRequest(SessionIndices:string, TableIdType:enum, TableId:number, ErrorUnsupportedTypeFormat:null)
			Args:
				args[0] is SessionIndices (str): This parameter requires a tableIdType of type kEnumValue=enumOpt-ALL_TABLE,enumOpt-MANUAL
				args[1] is TableIdType (str(enumOpt-ALL_TABLE|enumOpt-MANUAL)): This parameter requires a tableId of type kInteger
				args[2] is TableId (number): This parameter requires a errorUnsupportedTypeFormat of type kVoid
				args[3] is ErrorUnsupportedTypeFormat (null): This parameter requires a string of session numbers 1-4;6;7-12

		sendTableModRequest(Arg2:list, Arg3:enum, Arg4:number, Arg5:number)list
			Args:
				args[0] is Arg2 (list(number)): List of indices into the protocol plugin. An empty list indicates all instances in the plugin.
				args[1] is Arg3 (str(aLL_TABLE|manual)): Table ID Type
				args[2] is Arg4 (number): Table ID
				args[3] is Arg5 (number): Table Config

			Returns:
				list(str): ID to associate each async action invocation

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('sendTableModRequest', payload=payload, response_object=None)

	def SendTableStatsRequest(self, *args, **kwargs):
		"""Executes the sendTableStatsRequest operation on the server.

		Send Table Stats Request to Switch

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		sendTableStatsRequest()

		sendTableStatsRequest(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		sendTableStatsRequest(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		sendTableStatsRequest(Arg2:list)list
			Args:
				args[0] is Arg2 (list(number)): List of indices into the protocol plugin. An empty list indicates all instances in the plugin.

			Returns:
				list(str): ID to associate each async action invocation

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('sendTableStatsRequest', payload=payload, response_object=None)

	def Start(self, *args, **kwargs):
		"""Executes the start operation on the server.

		Start selected protocols.

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		start()

		start(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		start(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('start', payload=payload, response_object=None)

	def StartChannel(self, *args, **kwargs):
		"""Executes the startChannel operation on the server.

		Start OpenFlow Channel

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		startChannel()

		startChannel(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		startChannel(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('startChannel', payload=payload, response_object=None)

	def Stop(self, *args, **kwargs):
		"""Executes the stop operation on the server.

		Stop selected protocols.

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		stop()

		stop(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		stop(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('stop', payload=payload, response_object=None)

	def StopChannel(self, *args, **kwargs):
		"""Executes the stopChannel operation on the server.

		Stop OpenFlow Channel

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		stopChannel()

		stopChannel(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		stopChannel(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('stopChannel', payload=payload, response_object=None)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class Ppp(Base):
	"""The Ppp class encapsulates a required ppp node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the Ppp property from a parent instance.
	The internal properties list will contain one and only one set of properties which is populated when the property is accessed.
	"""

	_SDM_NAME = 'ppp'

	def __init__(self, parent):
		super(Ppp, self).__init__(parent)

	@property
	def ConfigurationRetries(self):
		"""The number of additional PPP configuration requests to send before beginning the termination process (if the peer is not properly acknowledging them). The default is 9 requests.

		Returns:
			number
		"""
		return self._get_attribute('configurationRetries')
	@ConfigurationRetries.setter
	def ConfigurationRetries(self, value):
		self._set_attribute('configurationRetries', value)

	@property
	def EnableAccmNegotiation(self):
		"""Enables negotiation of Asynchronous Control Character Mask (ACCM).

		Returns:
			bool
		"""
		return self._get_attribute('enableAccmNegotiation')
	@EnableAccmNegotiation.setter
	def EnableAccmNegotiation(self, value):
		self._set_attribute('enableAccmNegotiation', value)

	@property
	def EnableIpV4(self):
		"""Enables the IPv4 Network Control Protocol (IPCP).

		Returns:
			bool
		"""
		return self._get_attribute('enableIpV4')
	@EnableIpV4.setter
	def EnableIpV4(self, value):
		self._set_attribute('enableIpV4', value)

	@property
	def EnableIpV6(self):
		"""Enables the IPv6 Network Control Protocol (IPCP).

		Returns:
			bool
		"""
		return self._get_attribute('enableIpV6')
	@EnableIpV6.setter
	def EnableIpV6(self, value):
		self._set_attribute('enableIpV6', value)

	@property
	def EnableLqm(self):
		"""Enables Link Quality Monitoring (LQM) on the link.

		Returns:
			bool
		"""
		return self._get_attribute('enableLqm')
	@EnableLqm.setter
	def EnableLqm(self, value):
		self._set_attribute('enableLqm', value)

	@property
	def EnableMpls(self):
		"""Enables MPLS on the link.

		Returns:
			bool
		"""
		return self._get_attribute('enableMpls')
	@EnableMpls.setter
	def EnableMpls(self, value):
		self._set_attribute('enableMpls', value)

	@property
	def EnableOsi(self):
		"""Enables the Open System Interconnection (OSI) Network Layer Control Protocol (OSINLCP).

		Returns:
			bool
		"""
		return self._get_attribute('enableOsi')
	@EnableOsi.setter
	def EnableOsi(self, value):
		self._set_attribute('enableOsi', value)

	@property
	def Enabled(self):
		"""If true, enables PPP for the POS port.

		Returns:
			bool
		"""
		return self._get_attribute('enabled')
	@Enabled.setter
	def Enabled(self, value):
		self._set_attribute('enabled', value)

	@property
	def LocalIpAddress(self):
		"""The local port's requested IPv4 address. This address is sent by the local peer to the remote peer, as a Configuration Option in an IPCP Configuration Request packet. The default is 0.0.0.1.

		Returns:
			str
		"""
		return self._get_attribute('localIpAddress')
	@LocalIpAddress.setter
	def LocalIpAddress(self, value):
		self._set_attribute('localIpAddress', value)

	@property
	def LocalIpV6IdType(self):
		"""The type of Interface Identifier (IID). It is a Configuration Options sent in the Configuration Request packet. A globally unique, non-zero Interface Identifier is preferred.

		Returns:
			str(ipV6|lastNegotiated|macBased|random)
		"""
		return self._get_attribute('localIpV6IdType')
	@LocalIpV6IdType.setter
	def LocalIpV6IdType(self, value):
		self._set_attribute('localIpV6IdType', value)

	@property
	def LocalIpV6Iid(self):
		"""(a 64-bit/8-octet value) The IPv6 Interface Identifier. It MUST be unique on the link.

		Returns:
			str
		"""
		return self._get_attribute('localIpV6Iid')
	@LocalIpV6Iid.setter
	def LocalIpV6Iid(self, value):
		self._set_attribute('localIpV6Iid', value)

	@property
	def LocalIpV6MacBasedIid(self):
		"""(a 48-bit/6-octet value) The MAC Interface Identifier. It MUST be unique on the link.

		Returns:
			str
		"""
		return self._get_attribute('localIpV6MacBasedIid')
	@LocalIpV6MacBasedIid.setter
	def LocalIpV6MacBasedIid(self, value):
		self._set_attribute('localIpV6MacBasedIid', value)

	@property
	def LocalIpV6NegotiationMode(self):
		"""Before the negotiation of the Interface Identifier (IID), the node chooses a tentative Interface Identifier.

		Returns:
			str(localMay|localMust|peerMust)
		"""
		return self._get_attribute('localIpV6NegotiationMode')
	@LocalIpV6NegotiationMode.setter
	def LocalIpV6NegotiationMode(self, value):
		self._set_attribute('localIpV6NegotiationMode', value)

	@property
	def LqmReportInterval(self):
		"""The number of seconds between Link Quality Monitoring (LQM) reports.

		Returns:
			number
		"""
		return self._get_attribute('lqmReportInterval')
	@LqmReportInterval.setter
	def LqmReportInterval(self, value):
		self._set_attribute('lqmReportInterval', value)

	@property
	def PeerIpV6IdType(self):
		"""The type of Interface Identifier (IID). It is a Configuration Options sent in the Configuration Request packet. A globally unique, non-zero Interface Identifier is preferred.

		Returns:
			str(ipV6|lastNegotiated|macBased|random)
		"""
		return self._get_attribute('peerIpV6IdType')
	@PeerIpV6IdType.setter
	def PeerIpV6IdType(self, value):
		self._set_attribute('peerIpV6IdType', value)

	@property
	def PeerIpV6Iid(self):
		"""(a 64-bit/8-octet value) The IPv6 Interface Identifier. It MUST be unique on the link.

		Returns:
			str
		"""
		return self._get_attribute('peerIpV6Iid')
	@PeerIpV6Iid.setter
	def PeerIpV6Iid(self, value):
		self._set_attribute('peerIpV6Iid', value)

	@property
	def PeerIpV6MacBasedIid(self):
		"""(a 48-bit/6-octet value) The MAC Interface Identifier. It MUST be unique on the link.

		Returns:
			str
		"""
		return self._get_attribute('peerIpV6MacBasedIid')
	@PeerIpV6MacBasedIid.setter
	def PeerIpV6MacBasedIid(self, value):
		self._set_attribute('peerIpV6MacBasedIid', value)

	@property
	def PeerIpV6NegotiationMode(self):
		"""Before the negotiation of the Interface Identifier (IID), the node chooses a tentative Interface Identifier.

		Returns:
			str(localMust|peerMay|peerMust)
		"""
		return self._get_attribute('peerIpV6NegotiationMode')
	@PeerIpV6NegotiationMode.setter
	def PeerIpV6NegotiationMode(self, value):
		self._set_attribute('peerIpV6NegotiationMode', value)

	@property
	def PppLinkState(self):
		"""(Read-only) Indicates the current port link state. If PPP is enabled, the fully operational link state is indicated as PPP Up.

		Returns:
			str
		"""
		return self._get_attribute('pppLinkState')

	@property
	def RetryTimeout(self):
		"""The time, in seconds, between retransmissions of successive configuration or termination requests. The default is 8 seconds.

		Returns:
			number
		"""
		return self._get_attribute('retryTimeout')
	@RetryTimeout.setter
	def RetryTimeout(self, value):
		self._set_attribute('retryTimeout', value)

	@property
	def RxAlignment(self):
		"""The byte alignment desired for Receive, in bytes. The default is 0 bytes.

		Returns:
			number
		"""
		return self._get_attribute('rxAlignment')
	@RxAlignment.setter
	def RxAlignment(self, value):
		self._set_attribute('rxAlignment', value)

	@property
	def RxMaxReceiveUnit(self):
		"""The maximum transmit frame size desired, in bytes. The default is 65,535 bytes.

		Returns:
			number
		"""
		return self._get_attribute('rxMaxReceiveUnit')
	@RxMaxReceiveUnit.setter
	def RxMaxReceiveUnit(self, value):
		self._set_attribute('rxMaxReceiveUnit', value)

	@property
	def TxAlignment(self):
		"""The byte alignment desired for Transmit, in bytes. The default is 0 bytes.

		Returns:
			number
		"""
		return self._get_attribute('txAlignment')
	@TxAlignment.setter
	def TxAlignment(self, value):
		self._set_attribute('txAlignment', value)

	@property
	def TxMaxReceiveUnit(self):
		"""The maximum transmit frame size desired, in bytes. The default is 65,535 bytes.

		Returns:
			number
		"""
		return self._get_attribute('txMaxReceiveUnit')
	@TxMaxReceiveUnit.setter
	def TxMaxReceiveUnit(self, value):
		self._set_attribute('txMaxReceiveUnit', value)

	@property
	def UseMagicNumber(self):
		"""If enabled, magic number handling is enabled for negotiation and usage. The magic number is used primarily to detect looped connections.

		Returns:
			bool
		"""
		return self._get_attribute('useMagicNumber')
	@UseMagicNumber.setter
	def UseMagicNumber(self, value):
		self._set_attribute('useMagicNumber', value)

	def update(self, ConfigurationRetries=None, EnableAccmNegotiation=None, EnableIpV4=None, EnableIpV6=None, EnableLqm=None, EnableMpls=None, EnableOsi=None, Enabled=None, LocalIpAddress=None, LocalIpV6IdType=None, LocalIpV6Iid=None, LocalIpV6MacBasedIid=None, LocalIpV6NegotiationMode=None, LqmReportInterval=None, PeerIpV6IdType=None, PeerIpV6Iid=None, PeerIpV6MacBasedIid=None, PeerIpV6NegotiationMode=None, RetryTimeout=None, RxAlignment=None, RxMaxReceiveUnit=None, TxAlignment=None, TxMaxReceiveUnit=None, UseMagicNumber=None):
		"""Updates a child instance of ppp on the server.

		Args:
			ConfigurationRetries (number): The number of additional PPP configuration requests to send before beginning the termination process (if the peer is not properly acknowledging them). The default is 9 requests.
			EnableAccmNegotiation (bool): Enables negotiation of Asynchronous Control Character Mask (ACCM).
			EnableIpV4 (bool): Enables the IPv4 Network Control Protocol (IPCP).
			EnableIpV6 (bool): Enables the IPv6 Network Control Protocol (IPCP).
			EnableLqm (bool): Enables Link Quality Monitoring (LQM) on the link.
			EnableMpls (bool): Enables MPLS on the link.
			EnableOsi (bool): Enables the Open System Interconnection (OSI) Network Layer Control Protocol (OSINLCP).
			Enabled (bool): If true, enables PPP for the POS port.
			LocalIpAddress (str): The local port's requested IPv4 address. This address is sent by the local peer to the remote peer, as a Configuration Option in an IPCP Configuration Request packet. The default is 0.0.0.1.
			LocalIpV6IdType (str(ipV6|lastNegotiated|macBased|random)): The type of Interface Identifier (IID). It is a Configuration Options sent in the Configuration Request packet. A globally unique, non-zero Interface Identifier is preferred.
			LocalIpV6Iid (str): (a 64-bit/8-octet value) The IPv6 Interface Identifier. It MUST be unique on the link.
			LocalIpV6MacBasedIid (str): (a 48-bit/6-octet value) The MAC Interface Identifier. It MUST be unique on the link.
			LocalIpV6NegotiationMode (str(localMay|localMust|peerMust)): Before the negotiation of the Interface Identifier (IID), the node chooses a tentative Interface Identifier.
			LqmReportInterval (number): The number of seconds between Link Quality Monitoring (LQM) reports.
			PeerIpV6IdType (str(ipV6|lastNegotiated|macBased|random)): The type of Interface Identifier (IID). It is a Configuration Options sent in the Configuration Request packet. A globally unique, non-zero Interface Identifier is preferred.
			PeerIpV6Iid (str): (a 64-bit/8-octet value) The IPv6 Interface Identifier. It MUST be unique on the link.
			PeerIpV6MacBasedIid (str): (a 48-bit/6-octet value) The MAC Interface Identifier. It MUST be unique on the link.
			PeerIpV6NegotiationMode (str(localMust|peerMay|peerMust)): Before the negotiation of the Interface Identifier (IID), the node chooses a tentative Interface Identifier.
			RetryTimeout (number): The time, in seconds, between retransmissions of successive configuration or termination requests. The default is 8 seconds.
			RxAlignment (number): The byte alignment desired for Receive, in bytes. The default is 0 bytes.
			RxMaxReceiveUnit (number): The maximum transmit frame size desired, in bytes. The default is 65,535 bytes.
			TxAlignment (number): The byte alignment desired for Transmit, in bytes. The default is 0 bytes.
			TxMaxReceiveUnit (number): The maximum transmit frame size desired, in bytes. The default is 65,535 bytes.
			UseMagicNumber (bool): If enabled, magic number handling is enabled for negotiation and usage. The magic number is used primarily to detect looped connections.

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class LearnedMartiniLabel(Base):
	"""The LearnedMartiniLabel class encapsulates a system managed learnedMartiniLabel node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the LearnedMartiniLabel property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server by using the find method.
	"""

	_SDM_NAME = 'learnedMartiniLabel'

	def __init__(self, parent):
		super(LearnedMartiniLabel, self).__init__(parent)

	@property
	def CBit(self):
		"""If enabled, sets the C-Bit (flag). It is the highest order bit in the VC Type field. If the bit is set, it indicates the presence of a control word on this VC.

		Returns:
			bool
		"""
		return self._get_attribute('cBit')

	@property
	def Cas(self):
		"""Indicates the CAS value.

		Returns:
			str(e1Trunk|t1EsfTrunk|t1SfTrunk)
		"""
		return self._get_attribute('cas')

	@property
	def CemOption(self):
		"""The value of the CEM option.

		Returns:
			number
		"""
		return self._get_attribute('cemOption')

	@property
	def CemPayloadBytes(self):
		"""(For Circuit Emulation Service over MPLS/CEM). The length of the CEM payload (in bytes).

		Returns:
			number
		"""
		return self._get_attribute('cemPayloadBytes')

	@property
	def Description(self):
		"""An optional user-defined interface description. It may be used with ALL VC types. Valid length is 0 to 80 octets.

		Returns:
			str
		"""
		return self._get_attribute('description')

	@property
	def DisCeAddress(self):
		"""If the L2 interface type for the VC whose learned information is seen is IP, this field indicates the learned IP address of the remote end CE of the IP vrtual circuit.

		Returns:
			str
		"""
		return self._get_attribute('disCeAddress')

	@property
	def Frequency(self):
		"""Indicates the frequency.

		Returns:
			number
		"""
		return self._get_attribute('frequency')

	@property
	def GroupId(self):
		"""An arbitrary 32-bit value used to identify a group of VCs.

		Returns:
			number
		"""
		return self._get_attribute('groupId')

	@property
	def IncludeRtpHeader(self):
		"""If enables, includes the RTP information in the header.

		Returns:
			bool
		"""
		return self._get_attribute('includeRtpHeader')

	@property
	def Label(self):
		"""The label value added to the packet(s) by the upstream LDP peer.

		Returns:
			number
		"""
		return self._get_attribute('label')

	@property
	def LabelSpaceId(self):
		"""(2 octets) Identifies the set of labels that will be used. Part of the LDP identifier.

		Returns:
			number
		"""
		return self._get_attribute('labelSpaceId')

	@property
	def LocalPwSubStatus(self):
		"""It reflects the status carried in the PW status notification received from the peer.

		Returns:
			number
		"""
		return self._get_attribute('localPwSubStatus')

	@property
	def MaxAtmCell(self):
		"""The maximum number of ATM Cells which may be concatenated and sent in a single MPLS frame. This parameter is part of the FEC element.

		Returns:
			number
		"""
		return self._get_attribute('maxAtmCell')

	@property
	def Mtu(self):
		"""(in octets) The 2-octet value for the maximum Transmission Unit (MTU).

		Returns:
			number
		"""
		return self._get_attribute('mtu')

	@property
	def PayloadSize(self):
		"""Indicates the payload size.

		Returns:
			number
		"""
		return self._get_attribute('payloadSize')

	@property
	def PayloadType(self):
		"""The payload type.

		Returns:
			number
		"""
		return self._get_attribute('payloadType')

	@property
	def Peer(self):
		"""The RID of the upstream LDP peer. Part of the LSR ID. It must be globally unique. It forms the first 4 octets of the 6-octet LDP identifier.

		Returns:
			str
		"""
		return self._get_attribute('peer')

	@property
	def PeerPwSubStatus(self):
		"""It reflects the status carried in the PW status last sent to the peer.

		Returns:
			number
		"""
		return self._get_attribute('peerPwSubStatus')

	@property
	def PwState(self):
		"""The PseudoWire State - either Up or Down. For the PseudoWire to be Up (Up status), the VC ID, VC Type, and Peer must match.If the Enable VC Group Matching (on PseudoWire Status) option is enabled for the router, the VC Group ID must also be matched for the PseudoWire State to be Up.

		Returns:
			bool
		"""
		return self._get_attribute('pwState')

	@property
	def Sp(self):
		"""Indicates the SP value.

		Returns:
			str(hexVal1|hexVal2|hexVal3|hexVal4)
		"""
		return self._get_attribute('sp')

	@property
	def Ssrc(self):
		"""Indicates the SSRC value.

		Returns:
			number
		"""
		return self._get_attribute('ssrc')

	@property
	def TdmBitrate(self):
		"""The tdm bit rate.

		Returns:
			number
		"""
		return self._get_attribute('tdmBitrate')

	@property
	def TimestampMode(self):
		"""Indicates the timestamp mode.

		Returns:
			str(absolute|differential)
		"""
		return self._get_attribute('timestampMode')

	@property
	def VcId(self):
		"""The 32-bit VC connection identifier. Used with the VC type to identify a specific VC (for VC types 0x0001 to 0x000B).

		Returns:
			number
		"""
		return self._get_attribute('vcId')

	@property
	def VcType(self):
		"""The type of L2 VC depends on the Layer 2 protocol types.

		Returns:
			str(frameRelay|atmaal5|atmxCell|vlan|ethernet|hdlc|ppp|cem|atmvcc|atmvpc|ip|satopE1|satopT1|satopE3|satopT3|cesoPsnBasic|cesoPsnCas|frameRelayRfc4619)
		"""
		return self._get_attribute('vcType')

	def find(self, CBit=None, Cas=None, CemOption=None, CemPayloadBytes=None, Description=None, DisCeAddress=None, Frequency=None, GroupId=None, IncludeRtpHeader=None, Label=None, LabelSpaceId=None, LocalPwSubStatus=None, MaxAtmCell=None, Mtu=None, PayloadSize=None, PayloadType=None, Peer=None, PeerPwSubStatus=None, PwState=None, Sp=None, Ssrc=None, TdmBitrate=None, TimestampMode=None, VcId=None, VcType=None):
		"""Finds and retrieves learnedMartiniLabel data from the server.

		All named parameters support regex and can be used to selectively retrieve learnedMartiniLabel data from the server.
		By default the find method takes no parameters and will retrieve all learnedMartiniLabel data from the server.

		Args:
			CBit (bool): If enabled, sets the C-Bit (flag). It is the highest order bit in the VC Type field. If the bit is set, it indicates the presence of a control word on this VC.
			Cas (str(e1Trunk|t1EsfTrunk|t1SfTrunk)): Indicates the CAS value.
			CemOption (number): The value of the CEM option.
			CemPayloadBytes (number): (For Circuit Emulation Service over MPLS/CEM). The length of the CEM payload (in bytes).
			Description (str): An optional user-defined interface description. It may be used with ALL VC types. Valid length is 0 to 80 octets.
			DisCeAddress (str): If the L2 interface type for the VC whose learned information is seen is IP, this field indicates the learned IP address of the remote end CE of the IP vrtual circuit.
			Frequency (number): Indicates the frequency.
			GroupId (number): An arbitrary 32-bit value used to identify a group of VCs.
			IncludeRtpHeader (bool): If enables, includes the RTP information in the header.
			Label (number): The label value added to the packet(s) by the upstream LDP peer.
			LabelSpaceId (number): (2 octets) Identifies the set of labels that will be used. Part of the LDP identifier.
			LocalPwSubStatus (number): It reflects the status carried in the PW status notification received from the peer.
			MaxAtmCell (number): The maximum number of ATM Cells which may be concatenated and sent in a single MPLS frame. This parameter is part of the FEC element.
			Mtu (number): (in octets) The 2-octet value for the maximum Transmission Unit (MTU).
			PayloadSize (number): Indicates the payload size.
			PayloadType (number): The payload type.
			Peer (str): The RID of the upstream LDP peer. Part of the LSR ID. It must be globally unique. It forms the first 4 octets of the 6-octet LDP identifier.
			PeerPwSubStatus (number): It reflects the status carried in the PW status last sent to the peer.
			PwState (bool): The PseudoWire State - either Up or Down. For the PseudoWire to be Up (Up status), the VC ID, VC Type, and Peer must match.If the Enable VC Group Matching (on PseudoWire Status) option is enabled for the router, the VC Group ID must also be matched for the PseudoWire State to be Up.
			Sp (str(hexVal1|hexVal2|hexVal3|hexVal4)): Indicates the SP value.
			Ssrc (number): Indicates the SSRC value.
			TdmBitrate (number): The tdm bit rate.
			TimestampMode (str(absolute|differential)): Indicates the timestamp mode.
			VcId (number): The 32-bit VC connection identifier. Used with the VC type to identify a specific VC (for VC types 0x0001 to 0x000B).
			VcType (str(frameRelay|atmaal5|atmxCell|vlan|ethernet|hdlc|ppp|cem|atmvcc|atmvpc|ip|satopE1|satopT1|satopE3|satopT3|cesoPsnBasic|cesoPsnCas|frameRelayRfc4619)): The type of L2 VC depends on the Layer 2 protocol types.

		Returns:
			self: This instance with matching learnedMartiniLabel data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of learnedMartiniLabel data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the learnedMartiniLabel data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)



"""Sanity script
"""
import sys
import os
import json
from ixnetwork_restpy.testplatform.testplatform import TestPlatform
from ixnetwork_restpy.errors import IxNetworkError
from ixnetwork_restpy.files import Files

sessions = None

try:
    # test_platform = TestPlatform('10.36.78.53', platform='linux')
    test_platform = TestPlatform('127.0.0.1', rest_port=11009, platform='windows')
    test_platform.Trace = 'request_response'
    test_platform.Authenticate('admin', 'admin')
    print(test_platform)

    sessions = test_platform.Sessions.add()
    print(sessions)

    ixnetwork = sessions.Ixnetwork
    print(ixnetwork)
    ixnetwork.NewConfig()

    # create 2 ports
    vports = ixnetwork.Vport.add().add()

    # create a topology
    topology = ixnetwork.Topology.add(Name='Topology 1', Ports=vports)
    assert(len(topology) == 1)

    # create a device group
    device_group = topology.DeviceGroup.add(Name='Device 1', Multiplier='7')
    assert(len(device_group) == 1)
    device_group.Enabled.Alternate('False')
    assert (device_group.Enabled == 'Alt: False')
    
    # create and print ethernet information
    ethernet = device_group.Ethernet.add()
    assert(len(ethernet) == 1)

    # update multivalue on server immediately
    ethernet.Mac.Decrement(start_value='00:00:de:ad:be:ef', step_value='00:00:fa:ce:fa:ce')
    assert (ethernet.Mac == 'Dec: 00:00:de:ad:be:ef, 00:00:fa:ce:fa:ce')
    ethernet.Mac.Increment(start_value='00:00:fa:ce:fa:ce', step_value='00:00:de:ad:be:ef')
    assert (ethernet.Mac == 'Inc: 00:00:fa:ce:fa:ce, 00:00:de:ad:be:ef')
    ethernet.Mac.Random()
    assert (ethernet.Mac == 'Rand')
    ethernet.Mac.RandomRange()
    assert (ethernet.Mac.Pattern.startswith('Randr:'))
    ethernet.Mac.RandomMask()
    assert (ethernet.Mac.Pattern.startswith('Randb:'))
    ethernet.Mac.Distributed(algorithm='autoEven', mode='perPort', values=[('00:00:fa:ce:fa:ce', 60), ('0:00:de:ad:be:ef', 40)])
    assert (ethernet.Mac.Pattern.startswith('Dist:'))
    ethernet.Mac.ValueList(values=['00:00:fa:ce:fa:ce', '00:00:de:ad:be:ef'])
    assert (ethernet.Mac.Pattern.startswith('List:'))
    ethernet.Mac.Custom(start_value='00:00:fa:ce:fa:ce', step_value='00:00:de:ad:be:ef', increments=[('00:00:ab:ab:ab:ab', 6, [('00:00:01:01:01:01', 2, None)])])
    assert (ethernet.Mac.Pattern.startswith('Custom:'))
    print(ethernet.Mac.Values)
    
    ipv4 = ethernet.Ipv4.add(Name='Ipv4 1')
    print(ipv4)
    ipv4.Address.ValueList(['1.1.1.1', '1.1.1.2'])
    assert(ipv4.Address.Pattern.startswith('List:'))
    ipv4.Address.Increment(start_value='1.1.1.1', step_value='0.1.1.1')
    assert(ipv4.Address == 'Inc: 1.1.1.1, 0.1.1.1')
    
    ipv4.Start()
    
except IxNetworkError as e:
    print(e)

if sessions is not None:
    sessions.remove()





# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class NetworkTopology(Base):
	"""The NetworkTopology class encapsulates a user managed networkTopology node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the NetworkTopology property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server using the find method.
	The internal properties list can be managed by the user by using the add and remove methods.
	"""

	_SDM_NAME = 'networkTopology'

	def __init__(self, parent):
		super(NetworkTopology, self).__init__(parent)

	@property
	def ExternalLink(self):
		"""An instance of the ExternalLink class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.externallink.ExternalLink)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.externallink import ExternalLink
		return ExternalLink(self)

	@property
	def IsisDceSimulatedTopologyConfig(self):
		"""An instance of the IsisDceSimulatedTopologyConfig class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.isisdcesimulatedtopologyconfig.IsisDceSimulatedTopologyConfig)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.isisdcesimulatedtopologyconfig import IsisDceSimulatedTopologyConfig
		return IsisDceSimulatedTopologyConfig(self)

	@property
	def IsisL3SimulatedTopologyConfig(self):
		"""An instance of the IsisL3SimulatedTopologyConfig class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.isisl3simulatedtopologyconfig.IsisL3SimulatedTopologyConfig)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.isisl3simulatedtopologyconfig import IsisL3SimulatedTopologyConfig
		return IsisL3SimulatedTopologyConfig(self)

	@property
	def IsisSpbSimulatedTopologyConfig(self):
		"""An instance of the IsisSpbSimulatedTopologyConfig class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.isisspbsimulatedtopologyconfig.IsisSpbSimulatedTopologyConfig)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.isisspbsimulatedtopologyconfig import IsisSpbSimulatedTopologyConfig
		return IsisSpbSimulatedTopologyConfig(self)

	@property
	def IsisTrillSimulatedTopologyConfig(self):
		"""An instance of the IsisTrillSimulatedTopologyConfig class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.isistrillsimulatedtopologyconfig.IsisTrillSimulatedTopologyConfig)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.isistrillsimulatedtopologyconfig import IsisTrillSimulatedTopologyConfig
		return IsisTrillSimulatedTopologyConfig(self)

	@property
	def LdpSimulatedTopologyConfig(self):
		"""An instance of the LdpSimulatedTopologyConfig class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.ldpsimulatedtopologyconfig.LdpSimulatedTopologyConfig)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.ldpsimulatedtopologyconfig import LdpSimulatedTopologyConfig
		return LdpSimulatedTopologyConfig(self)

	@property
	def NetTopologyCustom(self):
		"""An instance of the NetTopologyCustom class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.nettopologycustom.NetTopologyCustom)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.nettopologycustom import NetTopologyCustom
		return NetTopologyCustom(self)

	@property
	def NetTopologyFatTree(self):
		"""An instance of the NetTopologyFatTree class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.nettopologyfattree.NetTopologyFatTree)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.nettopologyfattree import NetTopologyFatTree
		return NetTopologyFatTree(self)

	@property
	def NetTopologyGrid(self):
		"""An instance of the NetTopologyGrid class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.nettopologygrid.NetTopologyGrid)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.nettopologygrid import NetTopologyGrid
		return NetTopologyGrid(self)

	@property
	def NetTopologyHubNSpoke(self):
		"""An instance of the NetTopologyHubNSpoke class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.nettopologyhubnspoke.NetTopologyHubNSpoke)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.nettopologyhubnspoke import NetTopologyHubNSpoke
		return NetTopologyHubNSpoke(self)

	@property
	def NetTopologyLinear(self):
		"""An instance of the NetTopologyLinear class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.nettopologylinear.NetTopologyLinear)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.nettopologylinear import NetTopologyLinear
		return NetTopologyLinear(self)

	@property
	def NetTopologyMesh(self):
		"""An instance of the NetTopologyMesh class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.nettopologymesh.NetTopologyMesh)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.nettopologymesh import NetTopologyMesh
		return NetTopologyMesh(self)

	@property
	def NetTopologyRing(self):
		"""An instance of the NetTopologyRing class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.nettopologyring.NetTopologyRing)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.nettopologyring import NetTopologyRing
		return NetTopologyRing(self)

	@property
	def NetTopologyTree(self):
		"""An instance of the NetTopologyTree class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.nettopologytree.NetTopologyTree)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.nettopologytree import NetTopologyTree
		return NetTopologyTree(self)

	@property
	def OspfSimulatedTopologyConfig(self):
		"""An instance of the OspfSimulatedTopologyConfig class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.ospfsimulatedtopologyconfig.OspfSimulatedTopologyConfig)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.ospfsimulatedtopologyconfig import OspfSimulatedTopologyConfig
		return OspfSimulatedTopologyConfig(self)

	@property
	def Ospfv3SimulatedTopologyConfig(self):
		"""An instance of the Ospfv3SimulatedTopologyConfig class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.ospfv3simulatedtopologyconfig.Ospfv3SimulatedTopologyConfig)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.ospfv3simulatedtopologyconfig import Ospfv3SimulatedTopologyConfig
		return Ospfv3SimulatedTopologyConfig(self)

	@property
	def SimInterface(self):
		"""An instance of the SimInterface class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.siminterface.SimInterface)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.siminterface import SimInterface
		return SimInterface(self)

	@property
	def SimRouter(self):
		"""An instance of the SimRouter class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.simrouter.SimRouter)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.simrouter import SimRouter
		return SimRouter(self)

	@property
	def SimRouterBridge(self):
		"""An instance of the SimRouterBridge class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.simrouterbridge.SimRouterBridge)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.simrouterbridge import SimRouterBridge
		return SimRouterBridge(self)

	@property
	def Count(self):
		"""Number of elements inside associated multiplier-scaled container object, e.g. number of devices inside a Device Group

		Returns:
			number
		"""
		return self._get_attribute('count')

	@property
	def LinksPerNetwork(self):
		"""linksPerNetwork is controled by assigned topology

		Returns:
			number
		"""
		return self._get_attribute('linksPerNetwork')

	@property
	def NodesPerNetwork(self):
		"""Number of nodes in the Network Topology, including the root node defined in the parent Device Group

		Returns:
			number
		"""
		return self._get_attribute('nodesPerNetwork')

	def add(self):
		"""Adds a new networkTopology node on the server and retrieves it in this instance.

		Returns:
			self: This instance with all currently retrieved networkTopology data using find and the newly added networkTopology data available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._create(locals())

	def remove(self):
		"""Deletes all the networkTopology data in this instance from server.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._delete()

	def find(self, Count=None, LinksPerNetwork=None, NodesPerNetwork=None):
		"""Finds and retrieves networkTopology data from the server.

		All named parameters support regex and can be used to selectively retrieve networkTopology data from the server.
		By default the find method takes no parameters and will retrieve all networkTopology data from the server.

		Args:
			Count (number): Number of elements inside associated multiplier-scaled container object, e.g. number of devices inside a Device Group
			LinksPerNetwork (number): linksPerNetwork is controled by assigned topology
			NodesPerNetwork (number): Number of nodes in the Network Topology, including the root node defined in the parent Device Group

		Returns:
			self: This instance with matching networkTopology data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of networkTopology data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the networkTopology data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)

	def FetchAndUpdateConfigFromCloud(self, *args, **kwargs):
		"""Executes the fetchAndUpdateConfigFromCloud operation on the server.

		fetchAndUpdateConfigFromCloud(Mode:string)
			Args:
				args[0] is Mode (str): 

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('fetchAndUpdateConfigFromCloud', payload=payload, response_object=None)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class AdvFecRange(Base):
	"""The AdvFecRange class encapsulates a user managed advFecRange node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the AdvFecRange property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server using the find method.
	The internal properties list can be managed by the user by using the add and remove methods.
	"""

	_SDM_NAME = 'advFecRange'

	def __init__(self, parent):
		super(AdvFecRange, self).__init__(parent)

	@property
	def EnablePacking(self):
		"""(For IPv4 FEC ranges and in Unsolicited Label Distribution Mode ONLY) If checked, FEC ranges will be aggregated within a single LDP PDU to conserve bandwidth and processing.

		Returns:
			bool
		"""
		return self._get_attribute('enablePacking')
	@EnablePacking.setter
	def EnablePacking(self, value):
		self._set_attribute('enablePacking', value)

	@property
	def EnableReplyingLspPing(self):
		"""NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('enableReplyingLspPing')
	@EnableReplyingLspPing.setter
	def EnableReplyingLspPing(self, value):
		self._set_attribute('enableReplyingLspPing', value)

	@property
	def Enabled(self):
		"""Enables this FEC range for use in label mapping messages. By default, the Ixia LDP emulation uses the prefix FEC type.

		Returns:
			bool
		"""
		return self._get_attribute('enabled')
	@Enabled.setter
	def Enabled(self, value):
		self._set_attribute('enabled', value)

	@property
	def FirstNetwork(self):
		"""The first network address in the range (in IP address format).

		Returns:
			str
		"""
		return self._get_attribute('firstNetwork')
	@FirstNetwork.setter
	def FirstNetwork(self, value):
		self._set_attribute('firstNetwork', value)

	@property
	def LabelMode(self):
		"""Indicates whether the same label or incrementing labels should be used in the VC ranges.

		Returns:
			str(none|increment)
		"""
		return self._get_attribute('labelMode')
	@LabelMode.setter
	def LabelMode(self, value):
		self._set_attribute('labelMode', value)

	@property
	def LabelValueStart(self):
		"""The first label in the range of labels.

		Returns:
			number
		"""
		return self._get_attribute('labelValueStart')
	@LabelValueStart.setter
	def LabelValueStart(self, value):
		self._set_attribute('labelValueStart', value)

	@property
	def MaskWidth(self):
		"""The number of bits in the mask applied to the network address. The masked bits in the First Network address form the address prefix.

		Returns:
			number
		"""
		return self._get_attribute('maskWidth')
	@MaskWidth.setter
	def MaskWidth(self, value):
		self._set_attribute('maskWidth', value)

	@property
	def NumberOfNetworks(self):
		"""The number of network addresses to be included in the range. The maximum number of valid possible addresses depends on the values for the first network and the network mask.

		Returns:
			number
		"""
		return self._get_attribute('numberOfNetworks')
	@NumberOfNetworks.setter
	def NumberOfNetworks(self, value):
		self._set_attribute('numberOfNetworks', value)

	def update(self, EnablePacking=None, EnableReplyingLspPing=None, Enabled=None, FirstNetwork=None, LabelMode=None, LabelValueStart=None, MaskWidth=None, NumberOfNetworks=None):
		"""Updates a child instance of advFecRange on the server.

		Args:
			EnablePacking (bool): (For IPv4 FEC ranges and in Unsolicited Label Distribution Mode ONLY) If checked, FEC ranges will be aggregated within a single LDP PDU to conserve bandwidth and processing.
			EnableReplyingLspPing (bool): NOT DEFINED
			Enabled (bool): Enables this FEC range for use in label mapping messages. By default, the Ixia LDP emulation uses the prefix FEC type.
			FirstNetwork (str): The first network address in the range (in IP address format).
			LabelMode (str(none|increment)): Indicates whether the same label or incrementing labels should be used in the VC ranges.
			LabelValueStart (number): The first label in the range of labels.
			MaskWidth (number): The number of bits in the mask applied to the network address. The masked bits in the First Network address form the address prefix.
			NumberOfNetworks (number): The number of network addresses to be included in the range. The maximum number of valid possible addresses depends on the values for the first network and the network mask.

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def add(self, EnablePacking=None, EnableReplyingLspPing=None, Enabled=None, FirstNetwork=None, LabelMode=None, LabelValueStart=None, MaskWidth=None, NumberOfNetworks=None):
		"""Adds a new advFecRange node on the server and retrieves it in this instance.

		Args:
			EnablePacking (bool): (For IPv4 FEC ranges and in Unsolicited Label Distribution Mode ONLY) If checked, FEC ranges will be aggregated within a single LDP PDU to conserve bandwidth and processing.
			EnableReplyingLspPing (bool): NOT DEFINED
			Enabled (bool): Enables this FEC range for use in label mapping messages. By default, the Ixia LDP emulation uses the prefix FEC type.
			FirstNetwork (str): The first network address in the range (in IP address format).
			LabelMode (str(none|increment)): Indicates whether the same label or incrementing labels should be used in the VC ranges.
			LabelValueStart (number): The first label in the range of labels.
			MaskWidth (number): The number of bits in the mask applied to the network address. The masked bits in the First Network address form the address prefix.
			NumberOfNetworks (number): The number of network addresses to be included in the range. The maximum number of valid possible addresses depends on the values for the first network and the network mask.

		Returns:
			self: This instance with all currently retrieved advFecRange data using find and the newly added advFecRange data available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._create(locals())

	def remove(self):
		"""Deletes all the advFecRange data in this instance from server.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._delete()

	def find(self, EnablePacking=None, EnableReplyingLspPing=None, Enabled=None, FirstNetwork=None, LabelMode=None, LabelValueStart=None, MaskWidth=None, NumberOfNetworks=None):
		"""Finds and retrieves advFecRange data from the server.

		All named parameters support regex and can be used to selectively retrieve advFecRange data from the server.
		By default the find method takes no parameters and will retrieve all advFecRange data from the server.

		Args:
			EnablePacking (bool): (For IPv4 FEC ranges and in Unsolicited Label Distribution Mode ONLY) If checked, FEC ranges will be aggregated within a single LDP PDU to conserve bandwidth and processing.
			EnableReplyingLspPing (bool): NOT DEFINED
			Enabled (bool): Enables this FEC range for use in label mapping messages. By default, the Ixia LDP emulation uses the prefix FEC type.
			FirstNetwork (str): The first network address in the range (in IP address format).
			LabelMode (str(none|increment)): Indicates whether the same label or incrementing labels should be used in the VC ranges.
			LabelValueStart (number): The first label in the range of labels.
			MaskWidth (number): The number of bits in the mask applied to the network address. The masked bits in the First Network address form the address prefix.
			NumberOfNetworks (number): The number of network addresses to be included in the range. The maximum number of valid possible addresses depends on the values for the first network and the network mask.

		Returns:
			self: This instance with matching advFecRange data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of advFecRange data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the advFecRange data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class DceInterestedVlanRange(Base):
	"""The DceInterestedVlanRange class encapsulates a user managed dceInterestedVlanRange node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the DceInterestedVlanRange property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server using the find method.
	The internal properties list can be managed by the user by using the add and remove methods.
	"""

	_SDM_NAME = 'dceInterestedVlanRange'

	def __init__(self, parent):
		super(DceInterestedVlanRange, self).__init__(parent)

	@property
	def EnableIncludeInLsp(self):
		"""If true, enable a custom VLAN in the LSP.

		Returns:
			bool
		"""
		return self._get_attribute('enableIncludeInLsp')
	@EnableIncludeInLsp.setter
	def EnableIncludeInLsp(self, value):
		self._set_attribute('enableIncludeInLsp', value)

	@property
	def EnableIncludeInMgroupPdu(self):
		"""If true, enable and include VLAN in Mgroup PDU

		Returns:
			bool
		"""
		return self._get_attribute('enableIncludeInMgroupPdu')
	@EnableIncludeInMgroupPdu.setter
	def EnableIncludeInMgroupPdu(self, value):
		self._set_attribute('enableIncludeInMgroupPdu', value)

	@property
	def EnableM4Bit(self):
		"""If true, the M4 bit is enabled.

		Returns:
			bool
		"""
		return self._get_attribute('enableM4Bit')
	@EnableM4Bit.setter
	def EnableM4Bit(self, value):
		self._set_attribute('enableM4Bit', value)

	@property
	def EnableM6Bit(self):
		"""If true, the M6 bit is enabled.

		Returns:
			bool
		"""
		return self._get_attribute('enableM6Bit')
	@EnableM6Bit.setter
	def EnableM6Bit(self, value):
		self._set_attribute('enableM6Bit', value)

	@property
	def Enabled(self):
		"""Signifies if DCE Interested Vlan range is enabled or disabled.

		Returns:
			bool
		"""
		return self._get_attribute('enabled')
	@Enabled.setter
	def Enabled(self, value):
		self._set_attribute('enabled', value)

	@property
	def Nickname(self):
		"""The nickname of the VLAN range.

		Returns:
			number
		"""
		return self._get_attribute('nickname')
	@Nickname.setter
	def Nickname(self, value):
		self._set_attribute('nickname', value)

	@property
	def NoOfSpanningTreeRoots(self):
		"""The number of spanning tree roots for the VLAN.

		Returns:
			number
		"""
		return self._get_attribute('noOfSpanningTreeRoots')
	@NoOfSpanningTreeRoots.setter
	def NoOfSpanningTreeRoots(self, value):
		self._set_attribute('noOfSpanningTreeRoots', value)

	@property
	def StartSpanningTreeRootBridgeId(self):
		"""If true, starts the spanning tree root Bridge Id.

		Returns:
			str
		"""
		return self._get_attribute('startSpanningTreeRootBridgeId')
	@StartSpanningTreeRootBridgeId.setter
	def StartSpanningTreeRootBridgeId(self, value):
		self._set_attribute('startSpanningTreeRootBridgeId', value)

	@property
	def StartVlanId(self):
		"""The VLAN Id of first VLAN. Default is 1.

		Returns:
			number
		"""
		return self._get_attribute('startVlanId')
	@StartVlanId.setter
	def StartVlanId(self, value):
		self._set_attribute('startVlanId', value)

	@property
	def VlanCount(self):
		"""The count of the VLAN.

		Returns:
			number
		"""
		return self._get_attribute('vlanCount')
	@VlanCount.setter
	def VlanCount(self, value):
		self._set_attribute('vlanCount', value)

	@property
	def VlanIdStep(self):
		"""It shows the increment step of the VLAN. the default is 1.

		Returns:
			number
		"""
		return self._get_attribute('vlanIdStep')
	@VlanIdStep.setter
	def VlanIdStep(self, value):
		self._set_attribute('vlanIdStep', value)

	def update(self, EnableIncludeInLsp=None, EnableIncludeInMgroupPdu=None, EnableM4Bit=None, EnableM6Bit=None, Enabled=None, Nickname=None, NoOfSpanningTreeRoots=None, StartSpanningTreeRootBridgeId=None, StartVlanId=None, VlanCount=None, VlanIdStep=None):
		"""Updates a child instance of dceInterestedVlanRange on the server.

		Args:
			EnableIncludeInLsp (bool): If true, enable a custom VLAN in the LSP.
			EnableIncludeInMgroupPdu (bool): If true, enable and include VLAN in Mgroup PDU
			EnableM4Bit (bool): If true, the M4 bit is enabled.
			EnableM6Bit (bool): If true, the M6 bit is enabled.
			Enabled (bool): Signifies if DCE Interested Vlan range is enabled or disabled.
			Nickname (number): The nickname of the VLAN range.
			NoOfSpanningTreeRoots (number): The number of spanning tree roots for the VLAN.
			StartSpanningTreeRootBridgeId (str): If true, starts the spanning tree root Bridge Id.
			StartVlanId (number): The VLAN Id of first VLAN. Default is 1.
			VlanCount (number): The count of the VLAN.
			VlanIdStep (number): It shows the increment step of the VLAN. the default is 1.

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def add(self, EnableIncludeInLsp=None, EnableIncludeInMgroupPdu=None, EnableM4Bit=None, EnableM6Bit=None, Enabled=None, Nickname=None, NoOfSpanningTreeRoots=None, StartSpanningTreeRootBridgeId=None, StartVlanId=None, VlanCount=None, VlanIdStep=None):
		"""Adds a new dceInterestedVlanRange node on the server and retrieves it in this instance.

		Args:
			EnableIncludeInLsp (bool): If true, enable a custom VLAN in the LSP.
			EnableIncludeInMgroupPdu (bool): If true, enable and include VLAN in Mgroup PDU
			EnableM4Bit (bool): If true, the M4 bit is enabled.
			EnableM6Bit (bool): If true, the M6 bit is enabled.
			Enabled (bool): Signifies if DCE Interested Vlan range is enabled or disabled.
			Nickname (number): The nickname of the VLAN range.
			NoOfSpanningTreeRoots (number): The number of spanning tree roots for the VLAN.
			StartSpanningTreeRootBridgeId (str): If true, starts the spanning tree root Bridge Id.
			StartVlanId (number): The VLAN Id of first VLAN. Default is 1.
			VlanCount (number): The count of the VLAN.
			VlanIdStep (number): It shows the increment step of the VLAN. the default is 1.

		Returns:
			self: This instance with all currently retrieved dceInterestedVlanRange data using find and the newly added dceInterestedVlanRange data available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._create(locals())

	def remove(self):
		"""Deletes all the dceInterestedVlanRange data in this instance from server.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._delete()

	def find(self, EnableIncludeInLsp=None, EnableIncludeInMgroupPdu=None, EnableM4Bit=None, EnableM6Bit=None, Enabled=None, Nickname=None, NoOfSpanningTreeRoots=None, StartSpanningTreeRootBridgeId=None, StartVlanId=None, VlanCount=None, VlanIdStep=None):
		"""Finds and retrieves dceInterestedVlanRange data from the server.

		All named parameters support regex and can be used to selectively retrieve dceInterestedVlanRange data from the server.
		By default the find method takes no parameters and will retrieve all dceInterestedVlanRange data from the server.

		Args:
			EnableIncludeInLsp (bool): If true, enable a custom VLAN in the LSP.
			EnableIncludeInMgroupPdu (bool): If true, enable and include VLAN in Mgroup PDU
			EnableM4Bit (bool): If true, the M4 bit is enabled.
			EnableM6Bit (bool): If true, the M6 bit is enabled.
			Enabled (bool): Signifies if DCE Interested Vlan range is enabled or disabled.
			Nickname (number): The nickname of the VLAN range.
			NoOfSpanningTreeRoots (number): The number of spanning tree roots for the VLAN.
			StartSpanningTreeRootBridgeId (str): If true, starts the spanning tree root Bridge Id.
			StartVlanId (number): The VLAN Id of first VLAN. Default is 1.
			VlanCount (number): The count of the VLAN.
			VlanIdStep (number): It shows the increment step of the VLAN. the default is 1.

		Returns:
			self: This instance with matching dceInterestedVlanRange data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of dceInterestedVlanRange data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the dceInterestedVlanRange data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)
